@@ -42,7 +42,8 @@ sub new {
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $ParamObject     = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
 
     # get names of all parameters
     my @ParamNames = $ParamObject->GetParamNames();
@@ -60,11 +61,47 @@ sub Run {
             )
         {
             my @ParamArray = $ParamObject->GetArray( Param => $Key );
-            $GetParam{$Key} = \@ParamArray;
+
+            my @SafeParamArray;
+            for my $Value (@ParamArray) {
+                if ( defined $Value ) {
+                    my %SafeValue = $HTMLUtilsObject->Safety(
+                        String       => $Value,
+                        NoApplet     => 1,
+                        NoObject     => 1,
+                        NoEmbed      => 1,
+                        NoSVG        => 1,
+                        NoImg        => 1,
+                        NoIntSrcLoad => 1,
+                        NoExtSrcLoad => 1,
+                        NoJavaScript => 1,
+                    );
+
+                    $Value = $SafeValue{String};
+                }
+
+                push @SafeParamArray, $Value;
+            }
+
+            $GetParam{$Key} = \@SafeParamArray;
             next PARAMNAME;
         }
 
         $GetParam{$Key} = $ParamObject->GetParam( Param => $Key );
+        if ( !ref $GetParam{$Key} ) {
+            my %SafeGetParam = $HTMLUtilsObject->Safety(
+                String       => $GetParam{$Key},
+                NoApplet     => 1,
+                NoObject     => 1,
+                NoEmbed      => 1,
+                NoSVG        => 1,
+                NoImg        => 1,
+                NoIntSrcLoad => 1,
+                NoExtSrcLoad => 1,
+                NoJavaScript => 1,
+            );
+            $GetParam{$Key} = $SafeGetParam{String};
+        }
     }
 
     my $LayoutObject   = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
@@ -105,24 +142,27 @@ sub Run {
         my $ValidSelection     = $Self->_ValidSelectionGet();
         my %TicketAppointments = $Self->_TicketAppointments();
 
+        my $ColorPicker = $LayoutObject->ColorPicker(
+            Type    => 'InputField',
+            Name    => 'Color',
+            ID      => 'Color',
+            Color   => $Param{Color},
+            Palette => $ColorPalette,
+        );
+
         $LayoutObject->Block(
             Name => 'CalendarEdit',
             Data => {
                 GroupID      => $GroupSelection,
                 ValidID      => $ValidSelection,
                 Subaction    => 'StoreNew',
-                Color        => $ColorPalette->[ int rand( scalar @{$ColorPalette} ) ],
+                ColorPicker  => $ColorPicker,
                 Title        => Translatable('Add new Calendar'),
                 WidgetStatus => 'Collapsed',
                 %TicketAppointments,
             },
         );
 
-        $LayoutObject->AddJSData(
-            Key   => 'CalendarColorPalette',
-            Value => $ColorPalette,
-        );
-
         $Param{Action} = 'New';
     }
     elsif ( $Self->{Subaction} eq 'StoreNew' ) {
@@ -189,6 +229,14 @@ sub Run {
             my $ValidSelection     = $Self->_ValidSelectionGet(%GetParam);
             my %TicketAppointments = $Self->_TicketAppointments();
 
+            my $ColorPicker = $LayoutObject->ColorPicker(
+                Type    => 'InputField',
+                Name    => 'Color',
+                ID      => 'Color',
+                Color   => $Param{Color},
+                Palette => $ColorPalette,
+            );
+
             # get rule count
             my $RuleCount = scalar @{ $GetParam{TicketAppointments} || [] };
 
@@ -202,20 +250,11 @@ sub Run {
                     Subaction    => 'StoreNew',
                     Title        => Translatable('Add new Calendar'),
                     WidgetStatus => $RuleCount ? 'Expanded' : 'Collapsed',
+                    ColorPicker  => $ColorPicker,
                     %TicketAppointments,
                 },
             );
 
-            $LayoutObject->AddJSData(
-                Key   => 'CalendarColor',
-                Value => $GetParam{Color},
-            );
-
-            $LayoutObject->AddJSData(
-                Key   => 'CalendarColorPalette',
-                Value => $ColorPalette,
-            );
-
             $LayoutObject->AddJSData(
                 Key   => 'CalendarRuleCount',
                 Value => $RuleCount,
@@ -324,6 +363,13 @@ sub Run {
         my $ColorPalette       = $Self->_ColorPaletteGet();
         my $ValidSelection     = $Self->_ValidSelectionGet(%Calendar);
         my %TicketAppointments = $Self->_TicketAppointments();
+        my $ColorPicker        = $LayoutObject->ColorPicker(
+            Type    => 'InputField',
+            Name    => 'Color',
+            ID      => 'Color',
+            Color   => $Calendar{Color},
+            Palette => $ColorPalette,
+        );
 
         my $RuleCount = scalar @{ $Calendar{TicketAppointments} || [] };
 
@@ -336,20 +382,11 @@ sub Run {
                 Subaction    => 'Update',
                 Title        => Translatable('Edit Calendar'),
                 WidgetStatus => $RuleCount ? 'Expanded' : 'Collapsed',
+                ColorPicker  => $ColorPicker,
                 %TicketAppointments,
             },
         );
 
-        $LayoutObject->AddJSData(
-            Key   => 'CalendarColor',
-            Value => $Calendar{Color},
-        );
-
-        $LayoutObject->AddJSData(
-            Key   => 'CalendarColorPalette',
-            Value => $ColorPalette,
-        );
-
         $LayoutObject->AddJSData(
             Key   => 'CalendarRuleCount',
             Value => $RuleCount,
@@ -449,6 +486,13 @@ sub Run {
             my $ColorPalette       = $Self->_ColorPaletteGet();
             my $ValidSelection     = $Self->_ValidSelectionGet(%GetParam);
             my %TicketAppointments = $Self->_TicketAppointments();
+            my $ColorPicker        = $LayoutObject->ColorPicker(
+                Type    => 'InputField',
+                Name    => 'Color',
+                ID      => 'Color',
+                Color   => $Param{Color},
+                Palette => $ColorPalette,
+            );
 
             my $RuleCount = scalar @{ $GetParam{TicketAppointments} || [] };
 
@@ -462,20 +506,11 @@ sub Run {
                     Subaction    => 'Update',
                     Title        => Translatable('Edit Calendar'),
                     WidgetStatus => $RuleCount ? 'Expanded' : 'Collapsed',
+                    ColorPicker  => $ColorPicker,
                     %TicketAppointments,
                 },
             );
 
-            $LayoutObject->AddJSData(
-                Key   => 'CalendarColor',
-                Value => $Calendar{Color},
-            );
-
-            $LayoutObject->AddJSData(
-                Key   => 'CalendarColorPalette',
-                Value => $ColorPalette,
-            );
-
             $LayoutObject->AddJSData(
                 Key   => 'CalendarRuleCount',
                 Value => $RuleCount,
@@ -780,12 +815,12 @@ sub _ColorPaletteGet {
 
     # get color palette
     my $CalendarColors = $Kernel::OM->Get('Kernel::Config')->Get('AppointmentCalendar::CalendarColors') || [
-        '#000000', '#1E1E1E', '#3A3A3A', '#545453', '#6E6E6E', '#878687', '#888787', '#A09FA0',
-        '#B8B8B8', '#D0D0D0', '#E8E8E8', '#FFFFFF', '#891100', '#894800', '#888501', '#458401',
-        '#028401', '#018448', '#008688', '#004A88', '#001888', '#491A88', '#891E88', '#891648',
-        '#FF2101', '#FF8802', '#FFFA03', '#83F902', '#05F802', '#03F987', '#00FDFF', '#008CFF',
-        '#002EFF', '#8931FF', '#FF39FF', '#FF2987', '#FF726E', '#FFCE6E', '#FFFB6D', '#CEFA6E',
-        '#68F96E', '#68FDFF', '#68FBD0', '#6ACFFF', '#6E76FF', '#D278FF', '#FF7AFF', '#FF7FD3',
+        '#000000', '#1E1E1E', '#3A3A3A', '#891100', '#894800',
+        '#888501', '#458401', '#028401', '#018448', '#008688',
+        '#004A88', '#001888', '#491A88', '#891E88', '#891648',
+        '#FF2101', '#FF8802', '#FFFA03', '#83F902', '#05F802',
+        '#03F987', '#00FDFF', '#008CFF', '#002EFF', '#8931FF',
+        '#FF39FF', '#FF2987', '#FF726E', '#FFCE6E', '#FFFB6D',
     ];
 
     return $CalendarColors;
