@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -10,6 +10,7 @@ package Kernel::Modules::AdminOAuth2TokenManagement;
 
 use strict;
 use warnings;
+use utf8;
 
 use File::Basename;
 
@@ -186,6 +187,10 @@ sub _Overview {
         UserID => $Self->{UserID},
     );
 
+    $LayoutObject->Block(
+        Name => 'Filter',
+    );
+
     TOKENCONFIG:
     for my $TokenConfig (@TokenConfigs) {
         my $OAuth2TokenConfigIsInUse = $OAuth2TokenConfigObject->IsOAuth2TokenConfigInUse(
@@ -325,6 +330,8 @@ sub _EditTokenConfig {
                 $TokenConfig{Config}->{Requests}->{TokenByAuthorizationCode}->{Request}->{URL},
             TokenByRefreshTokenRequestURL =>
                 $TokenConfig{Config}->{Requests}->{TokenByRefreshToken}->{Request}->{URL},
+            Scope =>
+                $TokenConfig{Config}->{Scope},
             NotifyOnExpiredToken        => $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredToken},
             NotifyOnExpiredRefreshToken => $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredRefreshToken},
             ValidIDSelection            => $ValidIDSelection,
@@ -393,6 +400,8 @@ sub _AddTokenConfigByTemplateFile {
                 $TokenConfigTemplate->{Config}->{Requests}->{TokenByAuthorizationCode}->{Request}->{URL},
             TokenByRefreshTokenRequestURL =>
                 $TokenConfigTemplate->{Config}->{Requests}->{TokenByRefreshToken}->{Request}->{URL},
+            Scope =>
+                $TokenConfigTemplate->{Config}->{Scope},
             NotifyOnExpiredToken => $TokenConfigTemplate->{Config}->{Notifications}->{NotifyOnExpiredToken},
             NotifyOnExpiredRefreshToken =>
                 $TokenConfigTemplate->{Config}->{Notifications}->{NotifyOnExpiredRefreshToken},
@@ -417,7 +426,7 @@ sub _SaveTokenConfig {
     for my $GetParam (
         qw(
         ID TokenConfigTemplateFilename TokenConfigTemplateName Name ClientID ClientSecret
-        AuthorizationCodeRequestURL TokenByAuthorizationCodeRequestURL TokenByRefreshTokenRequestURL ValidID
+        AuthorizationCodeRequestURL TokenByAuthorizationCodeRequestURL TokenByRefreshTokenRequestURL Scope ValidID
         NotifyOnExpiredToken NotifyOnExpiredRefreshToken ContinueAfterSave
         )
         )
@@ -492,6 +501,7 @@ sub _SaveTokenConfig {
                 AuthorizationCodeRequestURL        => $GetParam{AuthorizationCodeRequestURL},
                 TokenByAuthorizationCodeRequestURL => $GetParam{TokenByAuthorizationCodeRequestURL},
                 TokenByRefreshTokenRequestURL      => $GetParam{TokenByRefreshTokenRequestURL},
+                Scope                              => $GetParam{Scope},
                 NotifyOnExpiredToken               => $GetParam{NotifyOnExpiredToken},
                 NotifyOnExpiredRefreshToken        => $GetParam{NotifyOnExpiredRefreshToken},
                 ValidIDSelection                   => $ValidIDSelection,
@@ -526,6 +536,7 @@ sub _SaveTokenConfig {
             = $GetParam{TokenByAuthorizationCodeRequestURL};
         $TokenConfig{Config}->{Requests}->{TokenByRefreshToken}->{Request}->{URL}
             = $GetParam{TokenByRefreshTokenRequestURL};
+        $TokenConfig{Config}->{Scope} = $GetParam{Scope};
         $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredToken} = $GetParam{NotifyOnExpiredToken} ? 1 : 0;
         $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredRefreshToken}
             = $GetParam{NotifyOnExpiredRefreshToken} ? 1 : 0;
@@ -566,6 +577,7 @@ sub _SaveTokenConfig {
             = $GetParam{TokenByAuthorizationCodeRequestURL};
         $TokenConfig{Config}->{Requests}->{TokenByRefreshToken}->{Request}->{URL}
             = $GetParam{TokenByRefreshTokenRequestURL};
+        $TokenConfig{Config}->{Scope} = $GetParam{Scope};
         $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredToken} = $GetParam{NotifyOnExpiredToken} ? 1 : 0;
         $TokenConfig{Config}->{Notifications}->{NotifyOnExpiredRefreshToken}
             = $GetParam{NotifyOnExpiredRefreshToken} ? 1 : 0;
