@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -8,8 +8,9 @@
 # --
 
 package Kernel::System::DateTime;
-## nofilter(TidyAll::Plugin::OTRS::Perl::Time)
-## nofilter(TidyAll::Plugin::OTRS::Perl::Translatable)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Time)
+## nofilter(TidyAll::Plugin::Znuny::Perl::Translatable)
+## nofilter(TidyAll::Plugin::Znuny::Perl::IsIntegerVariableCheck)
 
 use strict;
 use warnings;
@@ -194,12 +195,12 @@ Returns:
 
     my $DateTimeSettings = {
         Year      => 2016,
-        Month     => 1,         # starting at 1
+        Month     => 1,                 # starting at 1
         Day       => 22,
         Hour      => 16,
         Minute    => 35,
         Second    => 59,
-        DayOfWeek => 5,         # starting with 1 for Monday, ending with 7 for Sunday
+        DayOfWeek => 5,                 # starting with 1 for Monday, ending with 7 for Sunday
         TimeZone  => 'Europe/Berlin',
     };
 
@@ -997,14 +998,13 @@ Compares dates and returns a value suitable for using Perl's sort function (-1,
     my $Result = $DateTimeObject->Compare( DateTimeObject => $AnotherDateTimeObject );
 
 You can also use this as a function for Perl's sort:
-
-    my @SortedDateTimeObjects = sort { $a->Compare( DateTimeObject => $b ); } @UnsortedDateTimeObjects:
+    my @SortedDateTimeObjects = sort { $a->Compare( DateTimeObject => $b ) } @UnsortedDateTimeObjects;
 
 Returns:
 
-    $Result = -1;       # if date/time of $DateTimeObject < date/time of $AnotherDateTimeObject
-    $Result = 0;        # if date/time are equal
-    $Result = 1:        # if date/time of $DateTimeObject > date/time of $AnotherDateTimeObject
+    my $Result = -1;       # if date/time of $DateTimeObject < date/time of $AnotherDateTimeObject
+    my $Result = 0;        # if date/time are equal
+    my $Result = 1;        # if date/time of $DateTimeObject > date/time of $AnotherDateTimeObject
 
 =cut
 
@@ -1431,8 +1431,8 @@ Returns an array ref of available time zones.
     # This is useful to keep the obsolete time zone from a stored setting
     # so that it will e.g. be shown as selected when showing a selection list.
     # Otherwise the user would have to select a new time zone.
-    my $TimeZones = $DateTimeObject->TimeZoneList(
 
+    my $TimeZones = $DateTimeObject->TimeZoneList(
         # Africa/Kinshasa has become obsolete and has been replaced by Africa/Lagos.
         # This option will add Africa/Kinshasa to the list of time zones nonetheless.
         # The given time zone must be valid, so 'Some/InvalidTimeZone' will not be added.
@@ -1748,6 +1748,13 @@ Parses a date/time string and returns a hash ref.
     # Sets hour, minute and second to 0:
     my $DateTimeHash = $DateTimeObject->_StringToHash( String => '2016-08-14' );
 
+    # Format with time zone
+    my $DateTimeHash = $DateTimeObject->_StringToHash(
+        String   => '2023-02-17T11:00:00+03:00'
+        TimeZone => 'Europe/Berlin', # desired time zone of the created DateTime object, optional
+    );
+
+
 Please see C<L</new()>> for the list of supported string formats.
 
 Returns:
@@ -1815,12 +1822,9 @@ sub _StringToHash {
         #   If it isn't an offset consider it a timezone
         if ( $OffsetOrTZ !~ m/(\+|\-)\d{2}:?\d{2}/i ) {
 
-            # Make sure the time zone is valid. Otherwise, assume UTC.
-            if ( !$Self->IsTimeZoneValid( TimeZone => $OffsetOrTZ ) ) {
-                $OffsetOrTZ = 'UTC';
-            }
-
-            $OffsetOrTZ = $Self->GetRealTimeZone( TimeZone => $OffsetOrTZ );
+            # Make sure the time zone is valid. If it is an alias, replace it
+            # with the real name, otherwise assume UTC.
+            $OffsetOrTZ = $Self->GetRealTimeZone( TimeZone => $OffsetOrTZ ) // 'UTC';
 
             return {
                 %{$DateTimeHash},
@@ -1830,15 +1834,31 @@ sub _StringToHash {
 
         # It's an offset, get the time in GMT/UTC.
         $OffsetOrTZ =~ s/://i;    # Remove the ':'
-        my $DT = DateTime->new(
-            ( map { lcfirst $_ => $DateTimeHash->{$_} } keys %{$DateTimeHash} ),
-            time_zone => $OffsetOrTZ,
-        );
+
+        my $DT;
+        eval {
+            $DT = DateTime->new(
+                ( map { lcfirst $_ => $DateTimeHash->{$_} } keys %{$DateTimeHash} ),
+                time_zone => $OffsetOrTZ,
+            );
+        };
+        return if !$DT || ref $DT ne 'DateTime';
+
         $DT->set_time_zone('UTC');
-        $DT->set_time_zone( $Self->OTRSTimeZoneGet() );
+
+        my $TimeZone = $Param{TimeZone} // $Self->OTRSTimeZoneGet();
+        if (
+            $TimeZone ne 'UTC'    # because it's already UTC
+            && $Self->IsTimeZoneValid( TimeZone => $TimeZone )
+            )
+        {
+            $TimeZone = $Self->GetRealTimeZone( TimeZone => $TimeZone );
+            $DT->set_time_zone($TimeZone);
+        }
 
         return {
-            ( map { ucfirst $_ => $DT->$_() } qw(year month day hour minute second) )
+            ( map { ucfirst $_ => $DT->$_() } qw(year month day hour minute second) ),
+            TimeZone => $TimeZone,
         };
     }
 
@@ -1899,7 +1919,10 @@ sub _CPANDateTimeObjectCreate {
 
     # Create object from string
     if ( defined $Param{String} ) {
-        my $DateTimeHash = $Self->_StringToHash( String => $Param{String} );
+        my $DateTimeHash = $Self->_StringToHash(
+            String   => $Param{String},
+            TimeZone => $Param{TimeZone},
+        );
         if ( !IsHashRefWithData($DateTimeHash) ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 'Priority' => 'Error',
@@ -1910,7 +1933,11 @@ sub _CPANDateTimeObjectCreate {
         }
 
         %Param = (
+
+            # put time zone first because $DateTimeHash might contain one that has to be used
+            # and overwrites the one here
             TimeZone => $Param{TimeZone},
+
             %{$DateTimeHash},
         );
     }
